@@ -46,7 +46,19 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>UNKNOWN CUT</source>
+        <source>All</source>
+        <translation type="unfinished">Tous</translation>
+    </message>
+    <message>
+        <source>Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Macro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>invalid SQL or failed DB connection</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -67,10 +79,10 @@
     </message>
     <message>
         <source>Panel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Panneau</translation>
     </message>
     <message>
-        <source>Macro</source>
+        <source>Channel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -89,10 +101,6 @@
         <source>UNKNOWN</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Audio</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Marker</source>
         <translation type="unfinished"></translation>
@@ -117,6 +125,14 @@
         <source>Link</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Relative</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hard</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Traffic</source>
         <translation type="unfinished"></translation>
@@ -133,6 +149,178 @@
         <source>Tracker</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Text Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ASCAP/BMI Electronic Music Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Technical Playout Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SoundExchange Statutory License Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NPR/DS SoundExchange Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>RadioTraffic.com Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>VisualTraffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CounterPoint Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music1 Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Classical Music Playout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music Playout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music Summary</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>NaturalLog Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>WideOrbit Traffic Reconciliation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>FM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Report complete!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Report canceled!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open report file!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Main Log Output 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Main Log Output 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel First Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Audition/Cue Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aux Log 1 Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Aux Log 2 Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel Second Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel Third Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel Fourth Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sound Panel Fifth and Later Play Output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LiveAssist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatic</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previous</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UNKNOWN CUT</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>reserved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown Position</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Center</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Center</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Right</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Recording</source>
         <translation type="unfinished"></translation>
@@ -214,155 +402,11 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
+        <source>Mr. Master Reconciliation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Text Log</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>ASCAP/BMI Electronic Music Report</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Technical Playout Report</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SoundExchange Statutory License Report</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>RadioTraffic.com Traffic Reconciliation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>VisualTraffic Reconciliation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CounterPoint Traffic Reconciliation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Music1 Reconciliation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Other</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>AM</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>FM</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Report complete!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Report canceled!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to open report file!</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>invalid SQL or failed DB connection:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Music Summary</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>WideOrbit Traffic Reconciliation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unknown Position</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Top Left</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Top Center</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Top Right</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Bottom Left</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Bottom Center</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Bottom Right</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>NPR/DS SoundExchange Report</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Music Playout</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Main Log Output 1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Main Log Output 2</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound Panel First Play Output</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Aux Log 1 Output</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Aux Log 2 Output</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound Panel Second Play Output</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound Panel Third Play Output</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound Panel Fourth Play Output</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Audition/Cue Output</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound Panel Fifth and Later Play Output</source>
+        <source>Spin Count</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -398,11 +442,11 @@
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>No Available Cart Numbers</source>
@@ -465,20 +509,16 @@
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>RDLogEdit</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>The name is invalid!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>The service is invalid!</source>
         <translation type="unfinished"></translation>
@@ -508,11 +548,11 @@
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>PCM16</source>
@@ -535,41 +575,43 @@
     <name>RDButtonDialog</name>
     <message>
         <source>Edit Button</source>
-        <translation type="unfinished"></translation>
+        <translation>Modifier Bouton</translation>
     </message>
     <message>
         <source>Label:</source>
-        <translation type="unfinished"></translation>
+        <translation>Label :</translation>
     </message>
     <message>
         <source>Cart:</source>
-        <translation type="unfinished"></translation>
+        <translation>Cart :</translation>
     </message>
     <message>
         <source>Set
 Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Choisir
+Le Cart</translation>
     </message>
     <message>
         <source>Clear</source>
-        <translation type="unfinished"></translation>
+        <translation>Effacer</translation>
     </message>
     <message>
         <source>Set
 Color</source>
-        <translation type="unfinished"></translation>
+        <translation>Choisir
+La Couleur</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Annuler</translation>
     </message>
     <message>
         <source>NOT FOUND</source>
-        <translation type="unfinished"></translation>
+        <translation>NON TROUVE</translation>
     </message>
 </context>
 <context>
@@ -656,16 +698,20 @@ Color</source>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>ALL</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Show Only First</source>
         <translation type="unfinished"></translation>
@@ -675,7 +721,11 @@ Color</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Scheduler Code:</source>
+        <source>COMPOSER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>CONDUCTOR</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -687,12 +737,20 @@ Color</source>
         <source>Cart Error</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Unable to get temporary cart number for import!</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Unable to create temporary cart for import!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unable to get temporary cart number for import!</source>
+        <source>Importing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -703,15 +761,49 @@ Color</source>
         <source>Imported from</source>
         <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>RDCueEdit</name>
     <message>
-        <source>Importing...</source>
+        <source>&amp;Audition</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Importing</source>
+        <source>&amp;Pause</source>
+        <translation>&amp;Pause</translation>
+    </message>
+    <message>
+        <source>&amp;Stop</source>
+        <translation>&amp;Stop</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Début</translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation>Fin</translation>
+    </message>
+    <message>
+        <source>&amp;Recue</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDCueEditDialog</name>
+    <message>
+        <source>Set Cue Point</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;OK</source>
+        <translation type="unfinished">&amp;OK</translation>
+    </message>
+    <message>
+        <source>&amp;Cancel</source>
+        <translation type="unfinished">&amp;Annuler</translation>
+    </message>
+</context>
 <context>
     <name>RDCutDialog</name>
     <message>
@@ -773,16 +865,20 @@ Cart</source>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>ALL</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Show Only First</source>
         <translation type="unfinished"></translation>
@@ -791,10 +887,6 @@ Cart</source>
         <source>Matches</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Scheduler Code:</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>RDDateDialog</name>
@@ -804,11 +896,11 @@ Cart</source>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
 </context>
 <context>
@@ -850,7 +942,7 @@ Cart</source>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>Amplitude</source>
@@ -894,7 +986,7 @@ Out</source>
     </message>
     <message>
         <source>End</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Fin</translation>
     </message>
     <message>
         <source>Cut
@@ -1035,6 +1127,10 @@ Marker</source>
         <source>R</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Rivendell Web Service</source>
         <translation type="unfinished"></translation>
@@ -1044,10 +1140,6 @@ Marker</source>
 &quot;</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Edit Audio</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Marker Warning</source>
         <translation type="unfinished"></translation>
@@ -1067,19 +1159,19 @@ Are you sure you want to save?</source>
     <name>RDEditPanelName</name>
     <message>
         <source>Edit Panel Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Modifier le Nom du Panneau</translation>
     </message>
     <message>
         <source>Panel &amp;Name:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Nom :</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Annuler</translation>
     </message>
 </context>
 <context>
@@ -1155,11 +1247,11 @@ Overwrite?</source>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>PCM16</source>
@@ -1296,11 +1388,11 @@ figure for the report period.
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>Invalid ATH</source>
@@ -1323,11 +1415,11 @@ figure for the report period.
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
 </context>
 <context>
@@ -1401,7 +1493,7 @@ figure for the report period.
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>Export</source>
@@ -1445,7 +1537,7 @@ Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Export Error</source>
+        <source>Abort</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1453,7 +1545,7 @@ Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Abort</source>
+        <source>Export Error</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1461,11 +1553,11 @@ Do you want to overwrite it?</source>
     <name>RDIntegerDialog</name>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>Set Value</source>
@@ -1514,11 +1606,11 @@ Do you want to overwrite it?</source>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
 </context>
 <context>
@@ -1571,6 +1663,20 @@ Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RDLogLine</name>
+    <message>
+        <source>Panel</source>
+        <translation type="obsolete">Panneau</translation>
+    </message>
+</context>
+<context>
+    <name>RDPanelButton</name>
+    <message>
+        <source>No Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDPasswd</name>
     <message>
@@ -1579,11 +1685,11 @@ Do you want to overwrite it?</source>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;OK</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Annuler</translation>
     </message>
     <message>
         <source>&amp;Password:</source>
@@ -1611,31 +1717,31 @@ please try again!</source>
     <name>RDSoundPanel</name>
     <message>
         <source>Play All</source>
-        <translation type="unfinished"></translation>
+        <translation>Jouer tout</translation>
     </message>
     <message>
         <source>Play Hook</source>
-        <translation type="unfinished"></translation>
+        <translation>J. Marques</translation>
     </message>
     <message>
         <source>Reset</source>
-        <translation type="unfinished"></translation>
+        <translation>Effacer</translation>
     </message>
     <message>
         <source>All</source>
-        <translation type="unfinished"></translation>
+        <translation>Tous</translation>
     </message>
     <message>
         <source>Setup</source>
-        <translation type="unfinished"></translation>
+        <translation>Configurer</translation>
     </message>
     <message>
         <source>Cart</source>
-        <translation type="unfinished"></translation>
+        <translation>Cart</translation>
     </message>
     <message>
         <source>Panel</source>
-        <translation type="unfinished"></translation>
+        <translation>Panneau</translation>
     </message>
 </context>
 <context>
