@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdaudioconvert.cpp,v 1.14.2.2 2012/12/13 22:33:44 cvs Exp $
+//      $Id: rdaudioconvert.cpp,v 1.14.2.3.2.1 2014/05/15 16:30:00 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -46,6 +46,7 @@
 #include <rd.h>
 #include <rdaudioconvert.h>
 #include <rdlibrary_conf.h>
+#include <rdconf.h>
 
 #define STAGE2_XFER_SIZE 2048
 #define STAGE2_BUFFER_SIZE 49152
@@ -152,10 +153,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::convert()
   //
   // Generate Temporary Filenames
   //
-  strcpy(tmpdir,"/tmp");
-  if(getenv("TEMP")!=NULL) {
-    strncpy(tmpdir,getenv("TEMP"),PATH_MAX-20);
-  }
+  strcpy(tmpdir,RDTempDir());
   strcat(tmpdir,"/rdaudioconvertXXXXXX");
   if(mkdtemp(tmpdir)==NULL) {
     return RDAudioConvert::ErrorInternal;
@@ -309,6 +307,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Convert(const QString &srcfile,
       delete wave;
       return err;
 
+    case RDWaveFile::Aiff:
     case RDWaveFile::Unknown:
       break;
     }
@@ -431,7 +430,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Vorbis(const QString &dstfile,
 	ogg_stream_init(&ogg_stream,serialno);
       }
       if(ogg_stream_pagein(&ogg_stream,&ogg_page)==0) {
-	if(ogg_stream_packetout(&ogg_stream,&ogg_packet)==1) {
+	while(ogg_stream_packetout(&ogg_stream,&ogg_packet)==1) {
 	  switch(ogg_packet.packetno) {
 	  case 0:  // Start Packet
 	  case 1:  // Comment Packet
@@ -520,6 +519,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Vorbis(const QString &dstfile,
 #endif  // HAVE_VORBIS
 }
 
+#define STAGE1BUFSIZE 16384
 
 RDAudioConvert::ErrorCode RDAudioConvert::Stage1Mpeg(const QString &dstfile,
 						     RDWaveFile *wave)
@@ -533,7 +533,7 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Mpeg(const QString &dstfile,
   int left_over=0;
   int fsize;
   int n;
-  unsigned char buffer[2500];
+  unsigned char buffer[STAGE1BUFSIZE];
   float sf_buffer[1152*2];
   sf_count_t start=0;
   sf_count_t end=wave->getSampleLength();
@@ -581,11 +581,16 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Mpeg(const QString &dstfile,
     }
     mad_stream_buffer(&mad_stream,buffer,n+left_over);
     //printf("mad err: %d\n",mad_stream.error);
-   if(mad_stream.error==MAD_ERROR_LOSTSYNC) {  // FIXME: try to recover!!!
-     //    return RDAudioConvert::ErrorFormatError;
-     //break;
-    }
-    while(mad_frame_decode(&mad_frame,&mad_stream)==0) {
+   while(1) {
+
+      int thiserr=mad_frame_decode(&mad_frame,&mad_stream);
+      if(thiserr!=0) {
+	if(!MAD_RECOVERABLE(mad_stream.error))
+	  break;
+	else
+	  continue;
+      }
+
       //printf("decoding...\n");
       mad_synth_frame(&mad_synth,&mad_frame);
       for(int i=0;i<mad_synth.pcm.length;i++) {
@@ -625,9 +630,18 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage1Mpeg(const QString &dstfile,
 	}
       }
       frames+=mad_synth.pcm.length;
+
     }
     left_over=mad_stream.bufend-mad_stream.next_frame;
+
+    // Prevent buffer overflow on malformed files.
+    // The amount checked for should match the maximum amount that may be read
+    // by the next top-of-loop wave->readWave call.
+    if(left_over + fsize + 1 > STAGE1BUFSIZE)
+      return RDAudioConvert::ErrorFormatError;
+
     memmove(buffer,mad_stream.next_frame,left_over);
+
   }
   memset(buffer+left_over,0,MAD_BUFFER_GUARD);
   mad_stream_buffer(&mad_stream,buffer,MAD_BUFFER_GUARD+left_over);
@@ -866,8 +880,8 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
     // Speed
     //
     if(st_conv!=NULL) {
-      st_conv->putSamples(pcm[2],n);
-      n=st_conv->receiveSamples(pcm[2],STAGE2_BUFFER_SIZE/dst_info.channels);
+      st_conv->putSamples((soundtouch::SAMPLETYPE *)pcm[2],n);
+      n=st_conv->receiveSamples((soundtouch::SAMPLETYPE *)pcm[2],STAGE2_BUFFER_SIZE/dst_info.channels);
     }
 
     //
@@ -894,7 +908,8 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage2Convert(const QString &srcfile,
   if(st_conv!=NULL) {
     st_conv->flush();
     while((n=st_conv->
-	   receiveSamples(pcm[2],STAGE2_BUFFER_SIZE/dst_info.channels))>0) {
+	   receiveSamples((soundtouch::SAMPLETYPE *)pcm[2],
+			  STAGE2_BUFFER_SIZE/dst_info.channels))>0) {
       if(sf_writef_float(dst_sf,pcm[2],n)!=n) {
 	for(unsigned i=0;i<3;i++) {
 	  if(free_pcm[i]) {
@@ -1362,7 +1377,6 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer2Wav(SNDFILE *src_sf,
 							  const QString &dstfile)
 {
 #ifdef HAVE_TWOLAME
-  short *sf_buffer=NULL;
   sf_count_t n;
   ssize_t s;
   RDWaveFile *wave=NULL;
@@ -1416,7 +1430,6 @@ RDAudioConvert::ErrorCode RDAudioConvert::Stage3Layer2Wav(SNDFILE *src_sf,
   wave->setMextChunk(true);
   wave->setCartChunk(conv_dst_wavedata!=NULL);
   wave->setLevlChunk(true);
-  sf_buffer=new int16_t[2048*src_sf_info->channels];
   unlink(dstfile);
   if(!wave->createWave(conv_dst_wavedata)) {
     return RDAudioConvert::ErrorNoDestination;
