@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rddropbox.cpp,v 1.9 2010/07/29 19:32:33 cvs Exp $
+//      $Id: rddropbox.cpp,v 1.9.8.1 2013/12/11 20:17:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -204,6 +204,18 @@ void RDDropbox::setMetadataPattern(const QString &str) const
 }
 
 
+QString RDDropbox::userDefined() const
+{
+  return RDGetSqlValue("DROPBOXES","ID",box_id,"SET_USER_DEFINED").toString();
+}
+
+
+void RDDropbox::setUserDefined(const QString &str) const
+{
+  SetRow("SET_USER_DEFINED",str);
+}
+
+
 int RDDropbox::startdateOffset() const
 {
   return RDGetSqlValue("DROPBOXES","ID",box_id,"STARTDATE_OFFSET").toInt();
