@@ -2,9 +2,7 @@
 //
 // Abstract a Rivendell Switcher Matrix
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdmatrix.h,v 1.28.8.8 2013/11/17 04:27:04 cvs Exp $
+//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,7 +37,8 @@ class RDMatrix
 	     LogitekVguest=16,BtSs164=17,StarGuideIII=18,BtSs42=19,
 	     LiveWireLwrpAudio=20,Quartz1=21,BtSs44=22,BtSrc8III=23,BtSrc16=24,
 	     Harlond=25,Acu1p=26,LiveWireMcastGpio=27,Am16=28,
-	     LiveWireLwrpGpio=29,LastType=30};
+	     LiveWireLwrpGpio=29,BtSentinel4Web=30,BtGpi16=31,ModemLines=32,
+	     SoftwareAuthority=33,LastType=34};
   enum Endpoint {Input=0,Output=1};
   enum Mode {Stereo=0,Left=1,Right=2};
   enum VguestAttribute {VguestEngine=0,VguestDevice=1,VguestSurface=2,
