@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdpaths.h.in,v 1.1.2.2.2.1 2010/05/11 13:06:20 cvs Exp $
+//      $Id: rdpaths.h.in,v 1.6 2011/03/26 01:37:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -27,6 +27,23 @@
  * Rivendell Loadable Modules Directory
  */
 #define RD_MODULES_DIR "/usr/local/lib64/rivendell"
+
+/*
+ * Default Skins
+ */
+#define RD_DEFAULT_RDAIRPLAY_SKIN "/usr/local/share/pixmaps/rivendell/rdairplay_skin.png"
+#define RD_DEFAULT_RDPANEL_SKIN "/usr/local/share/pixmaps/rivendell/rdpanel_skin.png"
+
+/*
+ * CD Paranoia Includes
+ */
+extern "C" {
+#include <cdda/cdda_interface.h>
+}
+
+/*
+ * Installation Prefix
+ */
 #define RD_PREFIX "/usr/local"
 
 
