@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_svc.h,v 1.21.2.4 2010/02/02 00:30:30 cvs Exp $
+//      $Id: edit_svc.h,v 1.24.8.2 2014/01/10 15:40:15 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -59,8 +59,11 @@ class EditSvc : public QDialog
   RDSvc *svc_svc;
   QLineEdit *svc_name_edit;
   QLineEdit *svc_description_edit;
-  QLineEdit *svc_template_edit;
+  QLineEdit *svc_program_code_edit;
+  QLineEdit *svc_name_template_edit;
+  QLineEdit *svc_description_template_edit;
   QComboBox *svc_voice_group_box;
+  QComboBox *svc_autospot_group_box;
   QLineEdit *svc_tfc_path_edit;
   QLineEdit *svc_tfc_preimport_cmd_edit;
   QLineEdit *svc_tfc_win_path_edit;
