@@ -89,13 +89,16 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   //
   // Create Palettes
   //
+  QColor system_button_text_color = palette().active().buttonText();
+  QColor system_button_color = palette().active().button();
+  QColor system_mid_color = colorGroup().mid();
   list_from_color=
-    QPalette(QColor(BUTTON_FROM_BACKGROUND_COLOR),QColor(lightGray));
+    QPalette(QColor(BUTTON_FROM_BACKGROUND_COLOR),QColor(system_mid_color));
   list_from_color.
     setColor(QColorGroup::ButtonText,QColor(BUTTON_FROM_TEXT_COLOR));
 
   list_to_color=
-    QPalette(QColor(BUTTON_TO_BACKGROUND_COLOR),QColor(lightGray));
+    QPalette(QColor(BUTTON_TO_BACKGROUND_COLOR),QColor(system_mid_color));
   list_to_color.
     setColor(QColorGroup::ButtonText,QColor(BUTTON_TO_TEXT_COLOR));
   list_list_to_color=palette();
@@ -123,14 +126,26 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_scroll_color[0].setColor(QPalette::Active,QColorGroup::Button,
 			BUTTON_LOG_ACTIVE_BACKGROUND_COLOR);
   list_scroll_color[0].setColor(QPalette::Active,QColorGroup::Background,
-			lightGray);
+			system_mid_color);
   list_scroll_color[0].setColor(QPalette::Inactive,QColorGroup::ButtonText,
 			BUTTON_LOG_ACTIVE_TEXT_COLOR);
   list_scroll_color[0].setColor(QPalette::Inactive,QColorGroup::Button,
 			BUTTON_LOG_ACTIVE_BACKGROUND_COLOR);
   list_scroll_color[0].setColor(QPalette::Inactive,QColorGroup::Background,
-			lightGray);
-  list_scroll_color[1]=QPalette(backgroundColor(),lightGray);
+			system_mid_color);
+  list_scroll_color[1]=palette();
+  list_scroll_color[1].setColor(QPalette::Active,QColorGroup::ButtonText,
+                       system_button_text_color);
+  list_scroll_color[1].setColor(QPalette::Active,QColorGroup::Button,
+                       system_button_color);
+  list_scroll_color[1].setColor(QPalette::Active,QColorGroup::Background,
+			system_mid_color);
+  list_scroll_color[1].setColor(QPalette::Inactive,QColorGroup::ButtonText,
+                       system_button_text_color);
+  list_scroll_color[1].setColor(QPalette::Inactive,QColorGroup::Button,
+                       system_button_color);
+  list_scroll_color[1].setColor(QPalette::Inactive,QColorGroup::Background,
+			system_mid_color);
 
   //
   // Hour Selector
@@ -218,7 +233,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   label->setGeometry(372,sizeHint().height()-120,75,20);
   label->setFont(label_font);
   label->setAlignment(AlignCenter);  
-  label->setBackgroundColor(QColor(lightGray));
+  label->setBackgroundColor(QColor(system_mid_color));
   if(!rdairplay_conf->showCounters()) {
     label->hide();
   }
@@ -232,7 +247,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_stoptime_label->setGeometry(337,sizeHint().height()-100,65,18);
   list_stoptime_label->setFont(label_font);
   list_stoptime_label->setAlignment(AlignRight|AlignVCenter);  
-  list_stoptime_label->setBackgroundColor(QColor(lightGray));
+  list_stoptime_label->setBackgroundColor(QColor(system_mid_color));
   if(!rdairplay_conf->showCounters()) {
     list_stoptime_edit->hide();
     list_stoptime_label->hide();
@@ -243,14 +258,14 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   //
   list_endtime_edit=new QLineEdit(this,"list_endtime_edit");
   list_endtime_edit->setGeometry(407,sizeHint().height()-80,70,18);
-  label=new QLabel(list_endtime_edit,tr("Log End:"),this);
-  label->setGeometry(337,sizeHint().height()-80,65,18);
-  label->setFont(label_font);
-  label->setAlignment(AlignRight|AlignVCenter);  
-  label->setBackgroundColor(QColor(lightGray));
+  list_endtime_label=new QLabel(list_endtime_edit,tr("Log End:"),this);
+  list_endtime_label->setGeometry(337,sizeHint().height()-80,65,18);
+  list_endtime_label->setFont(label_font);
+  list_endtime_label->setAlignment(AlignRight|AlignVCenter);  
+  list_endtime_label->setBackgroundColor(QColor(system_mid_color));
   if(!rdairplay_conf->showCounters()) {
     list_endtime_edit->hide();
-    label->hide();
+    list_endtime_label->hide();
   }
 
   //
@@ -259,7 +274,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_take_button=new QPushButton(this,"list_take_button");
   list_take_button->setGeometry(10,sizeHint().height()-55,80,50);
   list_take_button->setFont(font);
-  list_take_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
+  list_take_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_take_button->setText(tr("Select"));
   list_take_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_take_button,SIGNAL(clicked()),this,SLOT(takeButtonData()));
@@ -271,7 +286,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_head_button=new QPushButton(this,"list_head_button");
   list_head_button->setGeometry(10,sizeHint().height()-113,80,50);
   list_head_button->setFont(font);
-  list_head_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
+  list_head_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_head_button->setText(tr("Audition\nHead"));
   list_head_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_head_button,SIGNAL(clicked()),this,SLOT(headButtonData()));
@@ -285,7 +300,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_tail_button=new QPushButton(this,"list_tail_button");
   list_tail_button->setGeometry(90,sizeHint().height()-113,80,50);
   list_tail_button->setFont(font);
-  list_tail_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
+  list_tail_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_tail_button->setText(tr("Audition\nTail"));
   list_tail_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_tail_button,SIGNAL(clicked()),this,SLOT(tailButtonData()));
@@ -299,7 +314,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_play_button=new QPushButton(this,"list_play_button");
   list_play_button->setGeometry(10,sizeHint().height()-55,80,50);
   list_play_button->setFont(font);
-  list_play_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
+  list_play_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_play_button->setText(tr("Start"));
   list_play_button->setDisabled(true);
   list_play_button->setFocusPolicy(QWidget::NoFocus);
@@ -311,8 +326,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_next_button=new QPushButton(this,"list_next_button");
   list_next_button->setGeometry(90,sizeHint().height()-55,80,50);
   list_next_button->setFont(font);
-  list_next_button->setPalette(QPalette(backgroundColor(),
-					  QColor(lightGray)));
+  list_next_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_next_button->setText(tr("Make\nNext"));
   list_next_button->setDisabled(true);
   list_next_button->setFocusPolicy(QWidget::NoFocus);
@@ -324,8 +338,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_modify_button=new QPushButton(this,"list_modify_button");
   list_modify_button->setGeometry(170,sizeHint().height()-55,80,50);
   list_modify_button->setFont(font);
-  list_modify_button->setPalette(QPalette(backgroundColor(),
-					  QColor(lightGray)));
+  list_modify_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_modify_button->setText(tr("Modify"));
   list_modify_button->setDisabled(true);
   list_modify_button->setFocusPolicy(QWidget::NoFocus);
@@ -337,8 +350,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_scroll_button=new QPushButton(this,"list_scroll_button");
   list_scroll_button->setGeometry(250,sizeHint().height()-55,80,50);
   list_scroll_button->setFont(font);
-  list_scroll_button->setPalette(QPalette(backgroundColor(),
-					  QColor(lightGray)));
+  list_scroll_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_scroll_button->setText(tr("Scroll"));
   list_scroll_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_scroll_button,SIGNAL(clicked()),this,SLOT(scrollButtonData()));
@@ -350,8 +362,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_refresh_button=new QPushButton(this,"list_refresh_button");
   list_refresh_button->setGeometry(330,sizeHint().height()-55,80,50);
   list_refresh_button->setFont(font);
-  list_refresh_button->
-    setPalette(QPalette(backgroundColor(),QColor(lightGray)));
+  list_refresh_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_refresh_button->setText(tr("Refresh\nLog"));
   list_refresh_button->setDisabled(true);
   list_refresh_button->setFocusPolicy(QWidget::NoFocus);
@@ -365,7 +376,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   list_load_button->setGeometry(sizeHint().width()-90,sizeHint().height()-55,
 				80,50);
   list_load_button->setFont(font);
-  list_load_button->setPalette(QPalette(backgroundColor(),QColor(lightGray)));
+  list_load_button->setPalette(QPalette(QColor(system_button_color),QColor(system_mid_color)));
   list_load_button->setText(tr("Select\nLog"));
   list_load_button->setFocusPolicy(QWidget::NoFocus);
   connect(list_load_button,SIGNAL(clicked()),this,SLOT(loadButtonData()));
@@ -397,7 +408,7 @@ ListLog::ListLog(LogPlay *log,int id,bool allow_pause,
   connect(list_log,SIGNAL(auditionStopped(int)),
 	  this,SLOT(auditionStoppedData(int)));
 
-  setBackgroundColor(QColor(lightGray));
+  setBackgroundColor(QColor(system_mid_color));
 
   RefreshList();
   UpdateTimes();
@@ -1054,12 +1065,10 @@ void ListLog::selectionChangedData()
 
 void ListLog::transportChangedData()
 {
-  int count=0;
   int transport_line[TRANSPORT_QUANTITY];
 
   SetColor();
 
-  count=0;
   list_log->transportEvents(transport_line);
   for(int i=0;i<TRANSPORT_QUANTITY;i++) {
     if(transport_line[i]!=-1) {
