@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_log.h,v 1.32.2.3 2010/02/08 23:50:14 cvs Exp $
+//      $Id: list_log.h,v 1.36.6.2 2013/12/28 00:00:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,8 +33,11 @@
 #include <rdlistviewitem.h>
 #include <rdairplay_conf.h>
 
+#include <lib_listview.h>
+#include <list_logs.h>
 #include <log_play.h>
 #include <edit_event.h>
+#include <hourselector.h>
 
 #define END_MARKER_ID -2
 
@@ -58,8 +61,10 @@ class ListLog : public QWidget
 
  signals:
   void selectClicked(int id,int line,RDLogLine::Status status);
+  void cartDropped(int id,int line,RDLogLine *ll);
 
  private slots:
+  void selectHour(int hour);
   void headButtonData();
   void tailButtonData();
   void auditionHeadData(int line);
@@ -83,6 +88,7 @@ class ListLog : public QWidget
   void transportChangedData();
   void modifiedData(int line);
   void refreshabilityChangedData(bool state);
+  void cartDroppedData(int line,RDLogLine *ll);
 
  protected:
   void paintEvent(QPaintEvent *e);
@@ -103,11 +109,16 @@ class ListLog : public QWidget
   void SetColor();
   void SetPlaybuttonMode(ListLog::PlayButtonMode mode);
   QString TimeString(const QTime &time) const;
-  RDListView *list_log_list;
+  void UpdateHourSelector();
+  int PredictedStartHour(RDListViewItem *item);
+  HourSelector *list_hour_selector;
+  LibListView *list_log_list;
   LogPlay *list_log;
+  ListLogs *list_logs_dialog;
   RDAirPlayConf::ActionMode list_action_mode;
   ListLog::PlayButtonMode list_playbutton_mode;
   EditEvent *list_event_edit;
+  QLabel *list_endtime_label;
   QLineEdit *list_endtime_edit;
   QLabel *list_stoptime_label;
   QLineEdit *list_stoptime_edit;
