@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary.cpp,v 1.117.4.18.2.1 2014/03/19 22:12:59 cvs Exp $
+//      $Id: rdlibrary.cpp,v 1.117.4.18.2.2 2014/05/22 14:30:45 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -1269,7 +1269,7 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 	    item->setBackgroundColor(RD_CART_ERROR_COLOR);
 	  }
 	  else {
-	    UpdateItemColor(item,(RDCart::Validity)q->value(21).toUInt(),
+	    UpdateItemColor(item,validity,
 			    q->value(13).toDateTime(),current_datetime);
 	  }
 	  break;
@@ -1357,6 +1357,10 @@ void MainWidget::UpdateItemColor(RDListViewItem *item,
 	}
 	break;
 	
+      case RDCart::FutureValid:
+	item->setBackgroundColor(RD_CART_FUTURE_COLOR);
+	break;
+	
       case RDCart::AlwaysValid:
 	item->setBackgroundColor(palette().color(QPalette::Active,
 					      QColorGroup::Base));
@@ -1401,16 +1405,24 @@ QString MainWidget::GetTypeFilter()
   return type_filter;
 }
 
+QString MainWidget::GeometryFile() {
+  bool home_found = false;
+  QString home = RDGetHomeDir(&home_found);
+  if (home_found) {
+    return home + "/" + RDLIBRARY_GEOMETRY_FILE;
+  } else {
+    return NULL;
+  }
+}
 
 void MainWidget::LoadGeometry()
 {
-  if(getenv("HOME")==NULL) {
+  QString geometry_file = GeometryFile();
+  if(geometry_file==NULL) {
     return;
   }
   RDProfile *profile=new RDProfile();
-  profile->
-    setSource(QString().sprintf("%s/%s",getenv("HOME"),
-				RDLIBRARY_GEOMETRY_FILE));
+  profile->setSource(geometry_file);
   resize(profile->intValue("RDLibrary","Width",sizeHint().width()),
 	 profile->intValue("RDLibrary","Height",sizeHint().height()));
   lib_shownotes_box->
@@ -1422,12 +1434,11 @@ void MainWidget::LoadGeometry()
 
 void MainWidget::SaveGeometry()
 {
-  if(getenv("HOME")==NULL) {
+  QString geometry_file = GeometryFile();
+  if(geometry_file==NULL) {
     return;
   }
-  FILE *file=fopen((const char *)QString().
-		   sprintf("%s/%s",getenv("HOME"),RDLIBRARY_GEOMETRY_FILE),
-		   "w");
+  FILE *file=fopen(geometry_file,"w");
   if(file==NULL) {
     return;
   }
