@@ -4,8 +4,6 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_clock.h,v 1.11.2.1 2008-11-30 00:33:00 fredg Exp $
-//
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
 //   published by the Free Software Foundation.
@@ -50,13 +48,14 @@ class EditClock : public QDialog
  Q_OBJECT
  public:
  EditClock(QString clockname,bool new_clock,std::vector<QString> *new_clocks,
-	    QWidget *parent=0,const char *name=0);
+	    QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
  private slots:
   void selectionChangedData(QListViewItem *);
   void addData();
+  void cloneData();
   void editData();
   void deleteData();
   void svcData();
