@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_grids.h,v 1.3 2007-02-14 21:57:04 fredg Exp $
+//      $Id: list_grids.h,v 1.5 2010/07/29 19:32:37 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -37,7 +37,7 @@ class ListGrids : public QDialog
 {
  Q_OBJECT
  public:
-  ListGrids(QWidget *parent=0,const char *name=0);
+  ListGrids(QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
