@@ -47,12 +47,14 @@
 #include <livewire_mcastgpio.h>
 #include <local_audio.h>
 #include <local_gpio.h>
+#include <modemlines.h>
 #include <quartz1.h>
 #include <sas32000.h>
 #include <sas64000.h>
 #include <sas64000gpi.h>
 #include <sasusi.h>
 #include <starguide3.h>
+#include <swauthority.h>
 #include <unity4000.h>
 #include <vguest.h>
 
@@ -153,6 +155,10 @@ bool MainObject::LoadSwitchDriver(int matrix_num)
     ripcd_switcher[matrix_num]=new VGuest(matrix,this);
     break;
 
+  case RDMatrix::ModemLines:
+    ripcd_switcher[matrix_num]=new ModemLines(matrix,this);
+    break;
+
   case RDMatrix::Quartz1:
     ripcd_switcher[matrix_num]=new Quartz1(matrix,this);
     break;
@@ -173,6 +179,10 @@ bool MainObject::LoadSwitchDriver(int matrix_num)
     ripcd_switcher[matrix_num]=new SasUsi(matrix,this);
     break;
 
+  case RDMatrix::SoftwareAuthority:
+    ripcd_switcher[matrix_num]=new SoftwareAuthority(matrix,this);
+    break;
+
   case RDMatrix::StarGuideIII:
     ripcd_switcher[matrix_num]=new StarGuide3(matrix,this);
     break;
